@@ -6,6 +6,8 @@
 @ GitHub : https://github.com/ZeroSeeker
 @ Gitee : https://gitee.com/ZeroSeeker
 """
+import copy
+
 from . import lazypath
 import collections
 import subprocess
@@ -19,20 +21,39 @@ import xlrd
 import json
 import sys
 import os
+import zipfile
 
-
-if platform.system() == 'Windows':
-    path_separator = '\\'
-else:
-    path_separator = '/'
 headers_default = {"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:68.0) Gecko/20100101 Firefox/68.0"}
 
 
+def delete(
+        file,
+        postfix: str = None,
+        path: str = None,
+):
+    """
+    删除文件
+    """
+    if path:
+        # 如果指定了路径，就加上路径
+        file_dir = os.path.join(path, file)
+    else:
+        # 如果没指定路径，就直接使用文件名
+        file_dir = file
+
+    if postfix:
+        # 如果指定了后缀名，就加上后缀名
+        file_dir = f'{file}.{postfix}'
+    else:
+        # 如果没指定后缀名，就忽略
+        pass
+    os.remove(file_dir)
+
+
 def get_suffix(
         file_name: str
 ):
-    suffix = file_name.split('.')[-1]  # 获取文件后缀名
-    return suffix
+    return file_name.split('.')[-1]  # 获取文件后缀名
 
 
 def file_rename(
@@ -90,12 +111,12 @@ def download(
     :param range_end:结束位置
     :return:
     """
-    if headers is None:
+    if not headers:
         headers_local = headers_default
     else:
         headers_local = headers
 
-    if range_start is None and range_end is None:
+    if not range_start and not range_end:
         range_start = 0
         range_info = None
     elif range_start is not None and range_end is None:
@@ -106,7 +127,7 @@ def download(
     else:
         range_info = 'bytes=%d-%d' % (range_start, range_end)
 
-    if range_info is None:
+    if not range_info:
         pass
     else:
         headers_local['Range'] = range_info
@@ -150,9 +171,9 @@ def download(
             pass
         else:
             os.makedirs(path)
-        path_local = path + path_separator + download_file_name
+        path_local = os.path.join(path, download_file_name)
 
-    if range_start is None:
+    if not range_start:
         temp_size = 0  # 已经下载文件大小
     else:
         temp_size = range_start + 0  # 已经下载文件大小
@@ -263,47 +284,91 @@ def safe_download(
 
 
 def read(
-        file_name,
-        postfix="txt",
-        path=None,
-        silence=False
+        file,
+        postfix: str = None,
+        path: str = None,
+        json_auto: bool = False,
+        read_lines: bool = False
 ):
-    try:
-        if postfix == "txt":
-            if path is None:
-                f = open("%s.%s" % (file_name, postfix), encoding='utf-8')
+    """
+    读取文件
+    json_auto：json格式自动转换
+    """
+    if path:
+        # 如果指定了路径，就加上路径
+        file_dir = os.path.join(path, file)
+    else:
+        # 如果没指定路径，就直接使用文件名
+        file_dir = file
+
+    if postfix:
+        # 如果指定了后缀名，就加上后缀名
+        file_dir = f'{file}.{postfix}'
+    else:
+        # 如果没指定后缀名，就忽略
+        pass
+
+    if read_lines:
+        with open(file=file_dir, mode='r', encoding='utf-8') as f:
+            content = f.readlines()
+    else:
+        f = open(file=file_dir, mode='r', encoding='utf-8')
+        content = f.read()
+
+    if content:
+        if json_auto:
+            if isinstance(content, str):
+                return json.loads(content)
             else:
-                f = open("%s/%s.%s" % (path, file_name, postfix), encoding='utf-8')
-            res = f.read()
-            return res
-        elif postfix == "json":
-            content_list = list()
-            if path is None:
-                with open("%s.%s" % (file_name, postfix), 'r', encoding='utf-8') as f:
-                    content = f.readlines()
-                    for each in content:
-                        each_json = json.loads(each)
-                        content_list.append(each_json)
-            else:
-                with open("./%s/%s.%s" % (path, file_name, postfix), 'r', encoding='utf-8') as f:
-                    content = f.readlines()
-                    for each in content:
-                        each_json = json.loads(each)
-                        content_list.append(each_json)
-            return content_list
+                json_content = list()
+                for each_line in content:
+                    json_content.append(json.loads(each_line))
+                return json_content
         else:
-            if path is None:
-                f = open("%s.%s" % (file_name, postfix), encoding='utf-8')
-            else:
-                f = open("%s/%s.%s" % (path, file_name, postfix), encoding='utf-8')
-            res = f.read()
-            return res
-    except Exception as e:
-        if silence is True:
-            pass
-        else:
-            showlog.warning(e)
-        return
+            return content
+    else:
+        return content
+
+
+def save(
+        file,
+        content,
+        suffix: str = None,
+        path: str = None,
+        overwrite: bool = True,
+        encoding: str = 'utf-8'
+) -> str:
+    """
+    保存文件
+    """
+    if path:
+        # 如果指定了路径，就加上路径
+        lazypath.make_path(path)
+        file_dir = os.path.join(path, file)
+    else:
+        # 如果没指定路径，就直接使用文件名
+        file_dir = file
+
+    if suffix:
+        # 如果指定了后缀名，就加上后缀名
+        file_dir = f'{file}.{suffix}'
+    else:
+        # 如果没指定后缀名，就忽略
+        pass
+
+    if overwrite is True:
+        write_mode = "w"  # 覆盖
+    else:
+        write_mode = "a"  # 追加
+
+    f = open(
+        file=file_dir,
+        mode=write_mode,
+        encoding=encoding
+    )
+    f.write(content)
+    f.close()
+    return file_dir
 
 
 def read_(_source_file):
@@ -323,114 +388,6 @@ def read_(_source_file):
     return res
 
 
-def excel_read(source_file):
-    # >>读取数据【方式：一次性全部读取】------------------------------------------------------------
-    data = xlrd.open_workbook(source_file)  # 打开表
-    res = list()
-    # table = data.sheets()[0]  # 默认使用第一张表格
-    for table in data.sheets():
-        nrows = table.nrows  # 获取行数
-        ncols = table.ncols  # 获取列数
-        for inrows in range(nrows):
-            res_temp = dict()
-            for incols in range(ncols):
-                res_temp.update({table.cell(0, incols).value: table.cell(inrows, incols).value})
-            # print(res_temp)
-            res.append(res_temp)
-    return res
-
-
-def excel_read_all_table(source_file):
-    try:
-        # >>读取数据【方式：一次性全部读取】------------------------------------------------------------
-        data = xlrd.open_workbook(source_file)  # 打开表
-        res = list()
-        # table = data.sheets()[0]  # 默认使用第一张表格
-        for table in data.sheets():
-            nrows = table.nrows  # 获取行数
-            ncols = table.ncols  # 获取列数
-            for inrows in range(nrows):
-                res_temp = dict()
-                for incols in range(ncols):
-                    res_temp.update({table.cell(0, incols).value: table.cell(inrows, incols).value})
-                # print(res_temp)
-                res.append(res_temp)
-        return res
-    except:
-        return
-
-
-def excel_sheet_dict(source_file):
-    try:
-        # >>读取数据【方式：一次性全部读取】------------------------------------------------------------
-        data = xlrd.open_workbook(source_file)  # 打开表
-        res = dict()
-        for table in data.sheets():
-            table_name = table.name
-            nrows = table.nrows  # 获取行数
-            ncols = table.ncols  # 获取列数
-            res_temp = list()
-            for inrows in range(nrows):
-                data_temp = dict()
-                for incols in range(ncols):
-                    data_temp.update({table.cell(0, incols).value: table.cell(inrows, incols).value})
-                res_temp.append(data_temp)
-            res.update({table_name: res_temp})
-        return res
-    except:
-        return
-
-
-def excel_specify_dict(source_file, sheet_name, _up_data_col_list=None, _col_dict=None):
-    try:
-        col_dict = dict()
-        if _col_dict is not None:
-            temp0 = _col_dict.replace(" ", "").split(",")
-            if temp0 is not None and len(temp0) > 0:
-                for each in temp0:
-                    temp1 = each.split(":")
-                    col_dict.update({temp1[1]: temp1[0]})
-        up_data_col_list = list()
-        if _up_data_col_list is not None:
-            up_data_col_list = _up_data_col_list.replace(" ", "").split(",")
-
-        # >>读取数据【方式：一次性全部读取】------------------------------------------------------------
-        data = xlrd.open_workbook(source_file)  # 打开表
-        res = dict()
-        for table in data.sheets():
-            table_name = table.name
-            if table_name == sheet_name:
-                nrows = table.nrows  # 获取行数
-                ncols = table.ncols  # 获取列数
-                res_temp = list()
-                for inrows in range(nrows):
-                    data_temp = dict()
-                    for incols in range(ncols):
-                        # print(table.cell(0, incols).value)
-                        col_name_ori = table.cell(0, incols).value
-                        if len(col_dict) > 0 and col_dict is not None:
-                            col_name = col_dict.get(col_name_ori)
-                        else:
-                            col_name = col_name_ori
-
-                        if col_name_ori in up_data_col_list:
-                            # print(col_name_ori)
-                            try:
-                                col_value = xlrd.xldate.xldate_as_datetime(table.cell(inrows, incols).value, 0)
-                            except Exception as ex:
-                                # print(ex)
-                                col_value = None
-                        else:
-                            col_value = table.cell(inrows, incols).value
-
-                        data_temp.update({col_name: col_value})
-                    res_temp.append(data_temp)
-                res.update({table_name: res_temp})
-        return res
-    except:
-        return
-
-
 def read_txt(text_name, path=None):
     try:
         if path is None:
@@ -494,30 +451,6 @@ class DateEncoder(json.JSONEncoder):
             return json.JSONEncoder.default(self, obj)
 
 
-def save(
-        file_name,
-        content,
-        postfix: str = "txt",
-        path=None,
-        overwrite=True
-):
-    """
-    增加自动创建目录功能
-    """
-    if overwrite is True:
-        write_mode = "w"  # 覆盖
-    else:
-        write_mode = "a"  # 追加
-
-    if path is None:
-        f = open("%s.%s" % (file_name, postfix), write_mode, encoding='utf-8')
-    else:
-        lazypath.make_path(path)
-        f = open("%s%s%s.%s" % (path, path_separator, file_name, postfix), write_mode, encoding='utf-8')
-    f.write(content)
-    f.close()
-
-
 def save_list(
         file_name,
         list_data,
@@ -533,7 +466,7 @@ def save_list(
         file_dir = "%s.%s" % (file_name, postfix)
     else:
         lazypath.make_path(path)
-        file_dir = "%s%s%s.%s" % (path, path_separator, file_name, postfix)
+        file_dir = os.path.join(path, f'{file_name}.{postfix}')
 
     if overwrite is True:
 
@@ -576,44 +509,151 @@ def dict_write07excel(path, table_name, sheet_name, data):
         showlog.info("导出数据成功！共计%s条数据" % len(data))
 
 
-def save_txt(
-        text_name,
-        content,
-        path=None,
-        overwrite=True):
-    """
-    是否覆写看overwrite参数
-    设置自动创建目录
-    """
-    if overwrite is True:
-        mode = "w"
-    else:
-        mode = "a"
-
-    if path is None:
-        f = open("%s.txt" % text_name, mode, encoding='utf-8')
-    else:
-        lazypath.make_path(path)
-        f = open("%s%s%s.txt" % (path, path_separator, text_name), mode, encoding='utf-8')
-    f.write(content)
-    f.close()
-
-
-def save_sql(
-        file_name,
-        content,
-        path=None
+def save_bytes(
+        bytes_content: bytes,
+        file: str
 ):
     """
-    如果文件存在，先清空，再保存
-    :param file_name:
-    :param content:
-    :param path:
-    :return:
+    保存bytes为文件
     """
-    if path is None:
-        f = open(file_name, "w", encoding='utf-8')
-    else:
-        f = open("%s%s%s.sql" % (path, path_separator, file_name), "w", encoding='utf-8')
-    f.write(content)
+    with open(file, 'wb') as f:
+        f.write(bytes_content)
     f.close()
+    return os.path.join(sys.path[0], file)
+
+
+def get_file_info(file_dir):
+    """
+    获取文件信息
+    """
+    from lazysdk import lazytime
+    file_path = os.path.dirname(file_dir)  # 获取文件路径
+    file_name = os.path.basename(file_dir)  # 获取不含路径信息的文件名
+    file_name_pure, file_suffix = os.path.splitext(file_name)  # 获取不含后缀名的文件名和后缀名
+    return {
+        'name': file_name,  # 获取不含路径信息的文件名
+        'path': file_path,
+        'pure_name': file_name_pure,
+        'suffix': file_suffix,
+        'size': get_file_size(file_dir=file_dir),
+        'create_timestamp': os.path.getctime(file_dir),
+        'create_time': lazytime.get_timestamp2datetime(os.path.getctime(file_dir)),
+        'modified_timestamp': os.path.getmtime(file_dir),
+        'modified_time': lazytime.get_timestamp2datetime(os.path.getmtime(file_dir)),
+    }
+
+
+def zip_file(
+        source_file: str,
+        zip_file: str = None
+) -> str:
+    """
+    压缩文件，此方法只适用于压缩单个文件，不适合压缩文件夹
+    """
+    import zipfile
+    file_path = os.path.dirname(source_file)
+    file_name = os.path.basename(source_file)
+    file_name_pure, file_suffix = os.path.splitext(file_name)
+    if not zip_file:
+        zip_file = os.path.join(file_path, f'{file_name_pure}.zip')
+    my_zip = zipfile.ZipFile(
+        file=zip_file,  # 打开一个对象，也就是目标文件名
+        mode='w'  # 写入模式
+    )
+    my_zip.write(
+        filename=source_file,  # 压缩目标文件路径
+        arcname=os.path.basename(source_file),  # 内部文件名
+        compress_type=zipfile.ZIP_DEFLATED
+    )
+    my_zip.close()
+    return zip_file
+
+
+def zip_path(
+        source_path
+) -> str:
+    """
+    压缩文件夹，并在原来的同级目录输出，返回zip文件路径
+    """
+    import shutil
+    return shutil.make_archive(
+        root_dir=source_path,
+        base_name=source_path,
+        format='zip'
+    )
+
+
+def make_zip(
+        file: str
+) -> str:
+    """
+    创建压缩文件，自动判断源是文件还是路径
+    """
+    if os.path.isdir(file):
+        return zip_path(file)
+    elif os.path.isfile(file):
+        return zip_file(file)
+    else:
+        return ''
+
+
+def unzip(
+        file
+) -> list:
+    """
+    解压文件，会在源文件的同级目录增加一个路径，以存放解压后的文件
+    返回的是一个已解压的所有文件路径的list
+    """
+    import zipfile
+    import locale
+    file_path = os.path.dirname(file)
+    file_name = os.path.basename(file)
+    file_name_pure, file_suffix = os.path.splitext(file_name)
+    encoding = locale.getpreferredencoding()
+    my_zip = zipfile.ZipFile(
+        file=file,
+        mode='r'
+    )
+    unzip_path = os.path.join(file_path, file_name_pure)
+    while True:
+        if os.path.exists(unzip_path):
+            unzip_path = f'{unzip_path}_unpack'
+        else:
+            break
+
+    # 生成一个源文件名对照正确文件名的字典
+    name_dict = dict()
+    for each in my_zip.filelist:
+        each_filename = copy.deepcopy(each.filename)
+        if each_filename[0:8] == '__MACOSX':
+            continue  # 屏蔽mac下的__MACOSX路径
+        else:
+            if each_filename.isascii():
+                pass   # 如果isascii=True，则不改编码
+            else:
+                try:
+                    each_filename = each_filename.encode('437').decode(encoding)  # 尝试使用437编码先解码，再编码
+                except:
+                    pass
+            name_dict[each.filename] = each_filename
+
+    unzip_names = list()
+    for each_name in my_zip.namelist():
+        new_name = name_dict.get(each_name)
+        if new_name:
+            new_name_dir = os.path.join(unzip_path, new_name)
+            extract_name = my_zip.extract(
+                member=each_name,
+                path=unzip_path
+            )
+            if extract_name == new_name_dir:
+                # print(extract_name)
+                pass
+            else:
+                # print(extract_name, '-->', new_name_dir)
+                os.renames(old=extract_name, new=new_name_dir)  # 对乱码文件名重命名
+                if os.path.isfile(new_name_dir):
+                    unzip_names.append(new_name_dir)
+        else:
+            continue
+    return unzip_names
