@@ -52,3 +52,26 @@ def get_url(
             # 这不是一个链接
             continue
     return url_list
+
+
+def path_clean(content):
+    """
+    清除路径前后可能出现的引号
+    """
+    if content[0] == '"' and content[-1] == '"':
+        content = content[1:-1]
+    elif content[0] == '“' and content[-1] == '”':
+        content = content[1:-1]
+    elif content[0] == "'" and content[-1] == "'":
+        content = content[1:-1]
+    else:
+        pass
+    return content
+
+
+def file_name_format(text):
+    """
+    对文件名处理，避免特殊字符导致的无法存储的问题
+    """
+    text_new = re.sub(r'[\\/:*?"<>|\r\n]+', "_", text)  # 规避windows非法字符
+    return text_new
