@@ -6,6 +6,7 @@
 @ GitHub : https://github.com/ZeroSeeker
 @ Gitee : https://gitee.com/ZeroSeeker
 """
+import requests
 import datetime
 import pytz
 import time
@@ -328,11 +329,20 @@ def get_datetime2timestamp(
 
 
 def get_datetime2date(
-        datetime_str: str
-):
-    datetime_timestamp = get_datetime2timestamp(datetime_str)
-    date_str = get_timestamp2date(datetime_timestamp)
-    return date_str
+        datetime_str,
+        f: str = '%Y-%m-%d'
+) -> str:
+    """
+    datetime->date
+    """
+    if isinstance(datetime_str, str):
+        datetime_timestamp = get_datetime2timestamp(datetime_str)
+        date_str = get_timestamp2date(datetime_timestamp)
+        return date_str
+    elif isinstance(datetime_str, datetime.datetime):
+        return datetime_str.strftime(f)
+    else:
+        return datetime_str
 
 
 def timestamp_day_num_start(
@@ -864,3 +874,60 @@ def get_gap_days(
     date2_date = datetime.datetime.strptime(date2, data2_f).date()
     days = (date2_date - date1_date).days
     return days
+
+
+def time_limit(
+        end_datetime: str
+):
+    """
+    时间限制
+    截止时间例如：2023-07-01 12:00:00
+    """
+    url = 'http://api.m.taobao.com/rest/api3.do?api=mtop.common.getTimestamp'  # 网络取时
+    res = requests.get(url=url)
+    net_t = res.json()['data']['t']
+    end_date_t = get_datetime2timestamp(end_datetime)
+    if end_date_t * 1000 > int(net_t):
+        seconds_left = end_date_t - int(net_t)/1000
+        print(f'剩余有效时长：{format_seconds(int(seconds_left))}')
+        return
+    else:
+        while True:
+            print('软件已失效，请联系开发者～')
+            time.sleep(1)
+
+
+def wait_hour(
+        hour: int,
+        sleep=0.01
+):
+    """
+    等待 小时整点，如果当前时间是指定的小时，将退出，否则将持续等待
+    hour为0-24的整数
+    sleep为等待检查的间隔时间
+    """
+    while True:
+        if datetime.datetime.now().hour == hour:
+            break
+        else:
+            time.sleep(sleep)
+
+
+def get_weekday():
+    """
+    获取当前时间的星期序列，星期1为1，星期日为7
+    """
+    return datetime.datetime.now().weekday() + 1
+
+
+def get_recent_days_date(
+        num_start: int = -1,
+        num_end: int = 0
+) -> list:
+    """
+    获取指定前推天数的日期列表
+    """
+    return date_str_list(
+        start_date=get_date_string(days=num_start),
+        end_date=get_date_string(days=num_end)
+    )
